youtubedlapi-server-infusiblecoder
=====================

A REST API server for getting the info for videos from different sites, powered by `youtube-dl <http://rg3.github.io/youtube-dl/>`_.
The installation instructions and the documentation are available at `Read the Docs <https://youtubedlapi-server-infusiblecoder.readthedocs.io/>`_.

About
-----

``youtubedlapi-server-infusiblecoder`` is released to the public domain, read the `license <LICENSE>`_ for more info.


Example
-----

youtubedlapi-server-infusiblecoder -p 8000 --host 127.0.0.1 --number-processes 1

